@@ -1,11 +1,11 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "datetime" "0.10.2"
+(define-package "datetime" "20250203.2047"
   "Parsing, formatting and matching timestamps."
   '((emacs  "25.1")
     (extmap "1.1.1"))
   :url "https://github.com/doublep/datetime"
-  :commit "b8e5fc2b7338f26ee816a3b03322c585dbd3b686"
-  :revdesc "b8e5fc2b7338"
+  :commit "2601120d4d2857cdbad1cf8d4b84d77308920835"
+  :revdesc "2601120d4d28"
   :keywords '("lisp" "i18n")
   :authors '(("Paul Pogonyshev" . "pogonyshev@gmail.com"))
   :maintainers '(("Paul Pogonyshev" . "pogonyshev@gmail.com")))
